@@ -1,18 +1,17 @@
 
 
 import unittest
-import sys
-sys.path.append('../')
+
 from nfstream import NFStreamer
-from plugins.n_pkts_byte_freq import NPacketsByteFrequency
-from plugins.dns_counter import DNSCounter
-from plugins.most_freq_payload_len_ratio import MostFreqPayloadLenRatio
-from plugins.small_pkt_payload_ratio import SmallPacketPayloadRatio
-from plugins.res_req_diff_time import ResReqDiffTime
-from plugins.pkt_rel_time import PacketRelativeTime
-from plugins.clump_flows import Clump_Flow
-from plugins.packets_size_interarrival_time import Packets_size_and_interarrival_time
-from plugins.n_bytes import NBytes
+from EIMTC.plugins.n_pkts_byte_freq import NPacketsByteFrequency
+from EIMTC.plugins.dns_counter import DNSCounter
+from EIMTC.plugins.most_freq_payload_len_ratio import MostFreqPayloadLenRatio
+from EIMTC.plugins.small_pkt_payload_ratio import SmallPacketPayloadRatio
+from EIMTC.plugins.res_req_diff_time import ResReqDiffTime
+from EIMTC.plugins.pkt_rel_time import PacketRelativeTime
+from EIMTC.plugins.clump_flows import Clump_Flow
+from EIMTC.plugins.packets_size_interarrival_time import Packets_size_and_interarrival_time
+from EIMTC.plugins.n_bytes import NBytes
 import numpy as np
 
 '''
